@@ -24,15 +24,18 @@ OpenTracing::Role::Tracer - Role for OpenTracin implementations.
 
 
 
-our $VERSION = '0.08_002';
+our $VERSION = '0.08_003';
 
 
 
 use Moo::Role;
 
 use Carp;
+use OpenTracing::Types qw/ScopeManager Span SpanContext/;
+use Role::Declare;
 use Try::Tiny;
-use Types::Standard qw/Object/;
+use Types::Common::Numeric qw/PositiveOrZeroNum/;
+use Types::Standard qw/HashRef Str/;
 
 
 
@@ -46,15 +49,14 @@ L<OpenTracing::Interface>.
 
 
 has scope_manager => (
-    is              => 'lazy',
-    isa             => Object,
+    is              => 'ro',
+    isa             => ScopeManager,
     reader          => 'get_scope_manager',
+    required        => 1,
 );
 
 
 
-requires 'build_span';
-
 requires 'extract_context';
 
 requires 'inject_context';
@@ -198,14 +200,15 @@ The followin must be implemented by consuming class
 
 =cut
 
-##### requires 'build_span';
-#
-# $self->build_span(
-#     operartion_name => $operation_name,
-#     start_time      => $start_time,
-#     tags            => \@tags,
-#     context         => $context,
-# );
+instance_method build_span (
+    
+    Str                 :$operation_name,
+    SpanContext | Span  :$child_of,
+    SpanContext         :$span_context,
+    PositiveOrZeroNum   :$start_time      = undef,
+    HashRef[Str]        :$tags            = {},
+    
+) :Return (Span) { };
 
 
 
